@@ -606,7 +606,7 @@
     <message>
         <location line="+219"/>
         <source>All</source>
-        <translation>Все</translation>
+        <translation>Информация</translation>
     </message>
     <message>
         <location line="-425"/>
@@ -649,7 +649,7 @@ Want to download more cities?</source>
     <message>
         <location line="+381"/>
         <source>Categories</source>
-        <translation>Категории</translation>
+        <translation>По категориям</translation>
     </message>
     <message>
         <location line="+253"/>
@@ -688,7 +688,7 @@ Want to download more cities?</source>
     <message>
         <location line="+637"/>
         <source>Swipe for change routes</source>
-        <translation>Свайп для изменения маршрута</translation>
+        <translation>Свайп для смены маршрута</translation>
     </message>
     <message>
         <location line="-569"/>
@@ -703,7 +703,7 @@ Want to download more cities?</source>
     <message>
         <location line="-8"/>
         <source>Custom font and style for station</source>
-        <translation>Настраиваемый шрифт для станции</translation>
+        <translation>Настроить шрифт станций</translation>
     </message>
     <message>
         <location line="+13"/>
@@ -741,17 +741,47 @@ Want to download more cities?</source>
     <message>
         <location line="+167"/>
         <source>Simple graphics for transfers*</source>
-        <translation>Упрощённая графика для переходов*</translation>
+        <translation>Простая графика переходов*</translation>
     </message>
     <message>
         <source>Background</source>
         <translation>Фон</translation>
     </message>
     <message>
-        <location filename="../../src/settings.cpp" line="+59"/>
+        <location filename="../../src/settings.cpp" line="+93"/>
+        <source>Update when starts</source>
+        <translation>Обновление при запуске</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Interval for check:</source>
+        <translation>Проверять через:</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Days</source>
+        <translation>Дней</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Check Now</source>
+        <translation>Обновить</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Last check:</source>
+        <translation>Прошлое:</translation>
+    </message>
+    <message>
+        <location line="-43"/>
         <source>Color...</source>
         <translation>Цвет...</translation>
     </message>
+    <message>
+        <location line="+173"/>
+        <source>never</source>
+        <translation>никогда</translation>
+    </message>
     <message>
         <location filename="../../ui/settings.ui" line="-320"/>
         <source>Shadow</source>
@@ -814,7 +844,7 @@ Want to download more cities?</source>
     <message>
         <location line="+10"/>
         <source>Fast scrolling (without antialiasing)</source>
-        <translation>Быстрый скроллинг (без сглаживания)</translation>
+        <translation>Прокрутка без сглаживания</translation>
     </message>
     <message>
         <source>Simple graphics for transfers</source>
@@ -828,12 +858,12 @@ Want to download more cities?</source>
     <message>
         <location line="+30"/>
         <source>Cache</source>
-        <translation>Кеш</translation>
+        <translation>Кеш карт</translation>
     </message>
     <message>
         <location line="+21"/>
         <source>Clean the cache on exit</source>
-        <translation>Очищать кеш при выходе</translation>
+        <translation>Очищать при выходе</translation>
     </message>
     <message>
         <location line="+58"/>
@@ -1162,4 +1192,47 @@ Want to download more cities?</source>
         <translation>Неизвестная ошибка.</translation>
     </message>
 </context>
+<context>
+    <name>TUpdate</name>
+    <message>
+        <location filename="../../src/update/update.cpp" line="+67"/>
+        <source>Updated version of qMetro is available for download at:</source>
+        <translation>Обновлённая версия qMetro доступна для загрузки:</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Installed</source>
+        <translation>Установлено</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>Available</source>
+        <translation>Доступно</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Update?</source>
+        <translation>Обновить?</translation>
+    </message>
+    <message>
+        <location line="+57"/>
+        <source>Updated maps available for download:</source>
+        <translation>Обновлённые карты доступны для загрузки:</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Maps</source>
+        <translation>Карты</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>Size</source>
+        <translation>Размер</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Download and install?</source>
+        <translation>Скачать и установить?</translation>
+    </message>
+</context>
 </TS>
