@@ -14,6 +14,12 @@
 #include "mapview/maplayer.h"
 #include "flickcharm.h"
 
+#ifdef Q_OS_SYMBIAN
+ #define _DEF( x ) QString(x).remove('"') // Symbian 474 "\"TEXT\""
+#else
+ #define _DEF( x ) QString(x)
+#endif
+
 #ifdef QMETRO_HAVE_ALARM
 #include "alarm/audiooutput.h"
 #endif
@@ -22,11 +28,11 @@
 //#include "alarm/vibro.h"
 #endif
 
-#ifdef Q_OS_SYMBIAN
-extern QString VERSION;
-#endif
+//#ifdef Q_OS_SYMBIAN
+//extern QString VERSION;
+//#endif
 extern MainWindow *mainWnd;
-extern QString appPath,URL_MAPS,SKIN_DEFAULT;
+extern QString appPath,URL_MAPS,SKIN_DEFAULT,URL_APP;
 
 class About : public QDialog
 {
@@ -42,7 +48,7 @@ public:
      OK=NULL;
      Info= new QTextBrowser();
      //Info->setStyleSheet("border:1px solid grey;");
-     setWindowTitle(tr("About")+" qMetro");
+     setWindowTitle(tr("About")+QString(" %1").arg(_DEF(APPNAME)));
 #ifdef Q_WS_MAEMO_5
      setAttribute(Qt::WA_Maemo5StackedWindow);
      setWindowFlags(Qt::Window);
@@ -71,10 +77,18 @@ public:
      }
 
      QString LIBS,MODULES=" (Core,Gui";
+
+#ifdef QMETRO_HAVE_UPDATE
+     MODULES+=",Network";
+#endif
 #ifdef QMETRO_HAVE_ALARM
      MODULES+=",Multimedia";
      LIBS+="<li>&nbsp;libmodplug";
 #endif
+#ifdef QMETRO_HAVE_NFC
+     MODULES+=",Connectivity";
+#endif
+
      MODULES+=")";
      QString hr=QString("<p><table height=\"2\" width=\"100%\" bgcolor=\"%1\"><tr><td></table></p>")
                 .arg(palette().color(QPalette::Mid).name());
@@ -83,23 +97,24 @@ public:
              "<img "+(0 ? QString("width=\"%1\" height=\"%1\"").arg(mainWnd->Config.appIconSize):"")+" align=\"left\" src=\":/qmetro.png\">"
              "<a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=9EZQ47YPVAF36\">"
              "<img "+(0 ? QString("width=\"%1\" height=\"%2\"").arg(mainWnd->Config.appIconSize).arg(mainWnd->Config.appIconSize/1.6):"")+" src=\":/img/donate.png\"></a>"
-             "<td><p><font size=6><b>qMetro</b></font>"
+             "<td><p><font size=6><b>"+_DEF(APPNAME)+"</b></font>"
 //          +"<br><sup><font size=5 color=\"#a90105\">"+tr("Happy New Year!")+"</font></sup>"+
              "<br>%4"
-             "<br><br>%5 %1<br>"
-             "&copy; 2011-2013<br><a href=\"mailto:guuleon@gmail.com\">Gusak Leonid</a><br>"
-             "<a href=\"http://qmetro.sf.net\">qmetro.sf.net</a></table></p>"
+             "<br><br>%5 %1<br>( "
+            +_DEF(QMETRO_PLATFORM)+
+             " )<br>&copy; 2011-2013<br><a href=\"mailto:guuleon@gmail.com\">Gusak Leonid</a><br>"
+             "<a href=\""+URL_APP+"\">"+URL_APP.remove("http://")+"</a></table></p>"
             +(mainWnd->Config.locale!="ru" ? "":"<br><center><table border=1><tr><td><small>WMR133269969667<small></table></center>")+
 
              "<hr><br>%6:<br><a href=\"mailto:Boris@pMetro.su\">Muradov Boris</a>"
              " (<a href=\"%10\">pMetro</a>)"
              "<br><br>%11"
             + AuthorOfSkin +
-             "<hr><b>%7 ("+QString("%1/%2").arg( mainWnd->map->nodeByID.count() ).arg( ((TMapLayer*)mainWnd->map->layer.at(0))->route.count() ) +"):</b>"
+             "<hr><b>%7 ("+QString("%1/%2").arg( mainWnd->map->nodeByID.count() ).arg( (mainWnd->map->layer.count() ? ((TMapLayer*)mainWnd->map->layer.at(0))->route.count() : 0) ) +"):</b>"
              "<p>%3</p>"
              "<hr><b>%8:</b><ul type=\"circle\"><li>&nbsp;Qt %2 %12</ul>"
              "<hr>%9")
-     .arg(VERSION).arg(QT_VERSION_STR+MODULES).arg((mainWnd->map->params.mapAuthors.isEmpty() ? tr("Unknown author"):mainWnd->map->params.mapAuthors)) // 1
+     .arg(_DEF(VERSION)).arg(QString(QT_VERSION_STR)+MODULES).arg((mainWnd->map->params.mapAuthors.isEmpty() ? tr("Unknown author"):mainWnd->map->params.mapAuthors)) // 1
      .arg(tr("transit system map")).arg(tr("Version")).arg(tr("Author of map file format")) // 3
      .arg(tr("About current map file")).arg(tr("This program uses")) // 6
      .arg(tr("This program is distributed in the hope that it will be useful, "
@@ -164,9 +179,8 @@ public:
      if(OK) delete OK;
      delete Info;
 #ifdef QMETRO_HAVE_ALARM
-     hide(); // alarm creating 1-2 sec  and can be deleting after
-     QApplication::processEvents();
-     delete Player;
+     hide();
+     playerDelete();
 #endif
 
     }
@@ -189,13 +203,13 @@ private:
 
 public slots:
 
- void playerDelete() { delete Player; Player=0; }
+ void playerDelete() { Player->deleteLater(); Player=0; }
  void playerCreate()
  {
   if(!Player)
   {
-   Player = new AudioPlay(this,":/audio/about.xm");
-   Player->start();
+   Player = new AudioPlay(":/audio/xmas.mdz",1);
+   QTimer::singleShot(5000,Player,SLOT(resumePlay()));
   }
  }
 
