@@ -33,11 +33,17 @@
 //#include <X11/Xlib.h>
 //#endif
 
-
 #ifdef Q_OS_SYMBIAN
-QString VERSION="0.6.8";
+ #define _DEF( x ) QString(x).remove('"') // Symbian 474 "\"TEXT\""
+#else
+ #define _DEF( x ) QString(x)
 #endif
 
+#ifndef QMETRO_PLATFORM
+#define QMETRO_PLATFORM "Source"
+#endif
+
+QString URL_APP="http://qmetro.sf.net";
 QString URL_MAPS="http://pmetro.su/Maps.html";
 QString URL_TRANSLATE="http://translate.google.com/translate?sl=ru&tl=%1&u=%2";
 
@@ -63,7 +69,7 @@ FlickCharm charm;
 
 IniSettingMap AppConfig;
 
-QString appPath, appConfigFile, cachePath;
+QString appPath, appConfigFile, appCachePath, appMapPath;
 
 QTranslator appTranslator;
 
@@ -75,6 +81,8 @@ QVector <QString> IniKeyStr;
 MainWindow::MainWindow(QWidget *parent) :
 QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NULL),Completer(NULL)
 {
+ qApp->setApplicationName(_DEF(APPNAME));
+
 #if defined(Q_OS_WINCE) || defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN) || defined(Q_OS_ANDROID)
  MobileVersion=1;
  qApp->setOverrideCursor(Qt::BlankCursor);
@@ -98,15 +106,23 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
 
 
  appPath=qApp->applicationDirPath()+"/";
- appConfigFile=cachePath="";
+ appConfigFile=appCachePath="";
 
 #if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
  QString home=qgetenv("HOME");
- appPath="/usr/share/qmetro/";
+ appPath=QString("%1/.local/share/data/%2/").arg(home).arg(APPNAME);
+ appMapPath=QString("%1/.local/share/data/%2/map/").arg(home).arg(APPNAME);
  if(!home.isEmpty())
  {
-  cachePath=home+"/.cache/qMetro/";
-  appConfigFile=home+"/.config/qMetro/config.conf";
+  appCachePath=QString("%1/.cache/%2/").arg(home).arg(APPNAME);
+  appConfigFile=QString("%1/.config/%2/config.conf").arg(home).arg(APPNAME);
+ }
+#endif
+#if defined(Q_OS_HAIKU)
+ QString home=qgetenv("HOME");
+ if(!home.isEmpty())
+ {
+  appConfigFile=QString("%1/config/settings/%2_settings").arg(home).arg(APPNAME);
  }
 #endif
 #if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
@@ -114,53 +130,39 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
  setAttribute(Qt::WA_Maemo5AutoOrientation);
  setAttribute(Qt::WA_Maemo5StackedWindow);
  setAttribute(Qt::WA_Maemo5NonComposited);
-// ICONSIZE=64;
  #else
- // MOBILE NONNATIVE INTERFACE
-// Config.appUiScale=2.5;
-// qApp->setStyle("cleanlooks");
  MobileVersion=2;
-
- // Orientation - set manually to portrait
-// #ifdef Q_WS_X11
-// WId id = this->winId();
-// Display *display = QX11Info::display();
-// if (!display) return;
-// Atom orientationAngleAtom = XInternAtom(display, "_MEEGOTOUCH_ORIENTATION_ANGLE", False);
-// XChangeProperty(display, id, orientationAngleAtom, XA_CARDINAL, 32, PropModeReplace, (unsigned char*)270, 1);
-// #endif
  #endif
- appPath="/home/user/MyDocs/Data/qMetro/";
- cachePath=appPath+"cache/";
- appConfigFile="/home/user/.config/qMetro/config.conf";
+
+ appPath=QString("/home/user/MyDocs/.local/share/%1/").arg(APPNAME);
+ appConfigFile=QString("/home/user/.config/%1/config.conf").arg(APPNAME);
 #endif
 #ifdef Q_OS_ANDROID
- appPath="/sdcard/Android/data/qMetro/";
- cachePath=appPath+".cache/";
-
- // MOBILE NONNATIVE INTERFACE
- //Config.appUiScale=2.5;
-// qApp->setStyle("cleanlooks");
-// qApp->setStyleSheet(
-//         "QWidget{background:black;color:#e9e6e9;border:1px solid #151715;}QPushButton{min-width:7em;min-height:4ex;background:#2f322f;border-top-color:#3d3d3d;text-align:center;}QGroupBox{border-top:2px solid #3d3d3d;border-bottom:2px solid #3d3d3d;color:#e9e6e9;margin:1em;} QGroupBox::title{subcontrol-origin:margin;subcontrol-position:top center;}QCheckBox::indicator:unchecked{border:1px solid #e9e6e9;}" );
+ appPath=QString("/sdcard/Android/data/%1/").arg(APPNAME);
  MobileVersion=2;
 #endif
 #ifdef Q_OS_SYMBIAN
- appPath="e:/Data/qMetro/";
-// ICONSIZE=56;
+ appPath=QString("e:/data/%1/").arg(_DEF(APPNAME));
 #endif
 
+ if(appMapPath.isEmpty()) appMapPath=appPath+"map/";
  if(appConfigFile.isEmpty()) appConfigFile=appPath+"config.ini";
- if(cachePath.isEmpty()) cachePath=appPath+"cache/";
+ if(appCachePath.isEmpty())
+ {
+  if(MobileVersion)
+       appCachePath=appPath+".cache/";
+  else appCachePath=appPath+"cache/";
+ }
  Config.appIconSize=ICONSIZE;
 
  QSettings *ini=new QSettings(appConfigFile,QSettings::IniFormat);
  ini->setIniCodec(codePage);
  QString key;
  ini->beginGroup("Main");
- if(VERSION!=ini->value("Version").toString())
+ if(_DEF(VERSION)!=ini->value("Version").toString())
  {
-  removeDir(cachePath);
+  removeDir(appCachePath);
+  if(MobileVersion) removeDir(appPath+"cache/"); // #OLD#
  }
 
  Config.mapKineticScrollCheck=0; // its work so bad...
@@ -222,7 +224,7 @@ QMainWindow(parent),map(NULL),SettingsWindow(NULL),ui(new Ui::MainWindow),mUi(NU
  //ui->labelLoading->setText("<H1>"+ui->labelLoading->text()+"</H1>");
  showPageLoading();
 
-#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD) || defined(Q_OS_HAIKU)
  ui->menuHelp->setIcon(QIcon());
 #endif
 #ifdef Q_OS_SYMBIAN
@@ -259,7 +261,7 @@ if(LITE)
 }
 
  qApp->setFont(Config.appFont);
- setWindowTitle(windowTitle()+(MobileVersion ? QString(""):QString(" ")+VERSION));
+ setWindowTitle(windowTitle()+(MobileVersion ? QString(""):QString(" ")+_DEF(VERSION)));
  if(Config.appFullscreen) //AppConfig.value(igMain).value(ikWFullScreen).toInt()
       toFullScreen();
  else (MobileVersion ? showMaximized():show());
@@ -272,14 +274,17 @@ if(LITE)
  //ui->eSearch->setText(tr("Find"));
  //ui->eSearch->installEventFilter(this);
 
- map = new TMapView(appPath,cachePath);
+ map = new TMapView(appPath,appCachePath);
  map->config.MobileVersion=MobileVersion;
  map->config.locale=Config.locale;
+ map->config.enableZoomKeys=ini->value("MapZoomKeys",1).toBool();
+ map->params.appMapPath=appMapPath;
+
  connect(map,SIGNAL(trackText(QString)),ui->textDescription,SLOT(setText(QString)));
  if(!MobileVersion)
  {
-   connect(map,SIGNAL(trackFinded(bool)),ui->mFind,SLOT(setChecked(bool))); // show description panel
-   connect(map,SIGNAL(trackShowIndex(int)),ui->cbRoute,SLOT(setCurrentIndex(int)));
+  connect(map,SIGNAL(trackFinded(bool)),ui->mFind,SLOT(setChecked(bool))); // show description panel
+  connect(map,SIGNAL(trackShowIndex(int)),ui->cbRoute,SLOT(setCurrentIndex(int)));
  }
 
  connect(map,SIGNAL(delayNames(QStringList)),this,SLOT(setDelayNames(QStringList)));
@@ -361,8 +366,11 @@ if(LITE)
   connect(map->nodePopup->actions().at(map->nodePopup->actions().count()-1), SIGNAL(triggered()),this, SLOT(nodeInformation()));
   map->nodePopup->addSeparator();
   map->nodePopup->addAction(tr("Start"));
+  QIcon fakeIcon(":/img/fake64.png");
+  map->nodePopup->actions().at(map->nodePopup->actions().count()-1)->setIcon(fakeIcon);
   connect(map->nodePopup->actions().at(map->nodePopup->actions().count()-1),SIGNAL(triggered()),map,SLOT(setNodeBegin()));
   map->nodePopup->addAction(tr("Finish"));
+  map->nodePopup->actions().at(map->nodePopup->actions().count()-1)->setIcon(fakeIcon);
   connect(map->nodePopup->actions().at(map->nodePopup->actions().count()-1),SIGNAL(triggered()),map,SLOT(setNodeEnd()));
   map->nodePopup->addSeparator();
   map->nodePopup->addAction(tr("Default start"));
@@ -406,7 +414,7 @@ if(LITE)
   ui->mSaveScale->setChecked(1);
   ui->mSavePosition->setChecked(1);
 #if !defined(QML_EDITION)
-  if(QMessageBox::question(this,windowTitle(),
+  if(QMessageBox::question(this,_DEF(APPNAME),
                            getMessageInstalledMaps(),QMessageBox::Yes|QMessageBox::No)==QMessageBox::Yes)
   {
    on_mAddMap_triggered();
@@ -436,14 +444,33 @@ if(LITE)
   map->verticalScrollBar()->setValue(Config.mapPosition.y()+yOffset);
  }
 
+
  // SWIPE!
  QGestureRecognizer* pRecognizer = new SwipeGestureRecognizer(qMin(qApp->desktop()->width(),qApp->desktop()->height())/qreal(1.2));
  m_gestureId = QGestureRecognizer::registerRecognizer(pRecognizer);
+
+ // UPDATE
+#ifdef QMETRO_HAVE_UPDATE
+ Updater = new TUpdate;
+ connect(Updater,SIGNAL(doneUpdateMaps()),this,SLOT(updateMapsAndReload()));
+#endif
+
+// NFC
+#ifdef QMETRO_HAVE_NFC
+ NFC = new TNFCTicket();
+#endif
 }
 
 MainWindow::~MainWindow()
 {
  QGestureRecognizer::unregisterRecognizer(m_gestureId);
+#ifdef QMETRO_HAVE_UPDATE
+ delete Updater;
+#endif
+#ifdef QMETRO_HAVE_NFC
+ delete NFC;
+#endif
+
  delete ui;
 }
 
@@ -502,8 +529,7 @@ void MainWindow::checkNodeDefault()
 
 bool MainWindow::eventFilter(QObject *obj, QEvent *e)
 {
-
- QMainWindow::event(e);
+ //QMainWindow::event(e);
  switch (e->type()) {
  case QEvent::LanguageChange:
   {
@@ -539,6 +565,7 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
     //if(windowState()==Qt::WindowFullScreen)
     ui->mFullScreen->setChecked(0); //showMaximized();
     map->clearTrack();
+    return 1;
    }
 
    if(key==Qt::Key_F1) on_mAbout_triggered();
@@ -582,7 +609,7 @@ void MainWindow::on_mExit_triggered()
 QString MainWindow::getMapDefaultDir()
 {
  if(map->params.mapFile.isEmpty())
-       return QString("%1map/").arg(appPath);
+       return appMapPath;
  else  return map->params.mapFile.left(map->params.mapFile.lastIndexOf("/")+1);
 }
 
@@ -605,15 +632,7 @@ void MainWindow::openMap(QString fileName)
  QString MapPath=getMapDefaultDir();
 
 // ZIPed maps will be unpacked and updated
- QDir Dir(MapPath);
- if (Dir.exists())
-  foreach(QFileInfo info, Dir.entryInfoList(QStringList()<<"*.zip",QDir::NoDotAndDotDot | QDir::Files))
-  {
-   QFile::remove(info.absolutePath()+"/"+info.baseName()+".pmz");
-   removeDir(cachePath+info.baseName());
-   map->extractFiles(info.absoluteFilePath(),"*.pmz",MapPath);
-   QFile::remove(info.absoluteFilePath());
-  }
+ updateMapsFromZips();
 
 if(fileName.isEmpty())
  fileName = QFileDialog::getOpenFileName(0,
@@ -630,7 +649,7 @@ if (fileName.isEmpty()) return;
 
 //testTimer.start();
  QString TempCache=fileName.section('/', -1 );
- TempCache=cachePath+TempCache.left(TempCache.indexOf("."))+"/";
+ TempCache=appCachePath+TempCache.left(TempCache.indexOf("."))+"/";
  QFile::remove(TempCache+".cache");
  QFile::remove(TempCache+".info");
  if(Completer) delete Completer;
@@ -647,6 +666,55 @@ if (fileName.isEmpty()) return;
  showPageMap();
 }
 
+void MainWindow::updateMapsFromZips()
+{
+ QString tmpMapPath=appMapPath+".update/";
+ QDir dir(appMapPath);
+ if (dir.exists())
+  foreach(QFileInfo info, dir.entryInfoList(QStringList()<<"*.zip",QDir::NoDotAndDotDot | QDir::Files))
+  {
+//   QString mapFileName=info.absolutePath()+"/"+info.baseName()+".pmz";
+//   QFile::remove(mapFileName);
+
+   removeDir(appCachePath+info.baseName());
+   map->extractFiles(info.absoluteFilePath(),"*.pmz",tmpMapPath);
+   QFile::remove(info.absoluteFilePath());
+  }
+
+ dir.setPath(tmpMapPath);
+ foreach(QFileInfo info, dir.entryInfoList(QStringList()<<"*.pmz",QDir::NoDotAndDotDot | QDir::Files))
+ {
+  QString newMapFile=appMapPath+info.fileName();
+  QFile::remove(newMapFile);
+  QFile::rename(tmpMapPath+info.fileName(),newMapFile);
+
+  QFile touch(newMapFile);
+  touch.open(QFile::ReadWrite);
+  touch.write(QString("P").toLatin1(),1); // touch for change modify date (P -> P)
+  touch.close();
+ }
+ removeDir(tmpMapPath);
+}
+
+void MainWindow::updateMapsAndReload()
+{
+ updateMapsFromZips();
+ reloadMap();
+}
+void MainWindow::reloadMap()
+{
+ qreal mapZoom = map->params.mapZoomFactor;
+ QPoint mapPos = QPoint(map->horizontalScrollBar()->value(),map->verticalScrollBar()->value());
+
+ map->mapStartDragging();
+ map->loadMap(map->params.mapFile);
+ map->fitInView(QRectF(0,0,map->mapWidth,map->mapHeight),Qt::KeepAspectRatioByExpanding);
+ map->scaleMap(mapZoom);
+ map->horizontalScrollBar()->setValue(mapPos.x());
+ map->verticalScrollBar()->setValue(mapPos.y());
+ map->mapStopDragging();
+}
+
 void MainWindow::loadSkin(QString skinName)
 {
 //qDebug() << 0 << skinName << SKIN_DEFAULT << Config.appSkinName;
@@ -657,11 +725,18 @@ void MainWindow::loadSkin(QString skinName)
  QString skinPath=appPath+"skin/";
  QDir Dir(skinPath);
  if(Dir.exists())
+ {
+  foreach(QFileInfo info, Dir.entryInfoList(QStringList()<<"*",QDir::NoDotAndDotDot | QDir::Dirs))
+  {
+   if(info.fileName().at(0)=='.') continue;
+   QFile::rename(info.absoluteFilePath(),info.absolutePath()+"/."+info.fileName());
+  }
   foreach(QFileInfo info, Dir.entryInfoList(QStringList()<<"*.zip",QDir::NoDotAndDotDot | QDir::Files))
   {
     map->extractFiles(info.absoluteFilePath(),"*",skinPath);
     QFile::remove(info.absoluteFilePath());
   }
+ }
 
  if(Config.appSkinName==skinName)
  {
@@ -669,7 +744,7 @@ void MainWindow::loadSkin(QString skinName)
   return;
  }
 
- QString fullPath=skinPath+skinName+"/";
+ QString fullPath=skinPath+"."+skinName+"/";
  QString styleSheet,value,url="url(",rc=":#(",args="/*%1%2%3%4%5%6%7*/";
 //qDebug() << 1;
 
@@ -949,7 +1024,7 @@ void infoAddTab(QWidget *widget, const QString &Caption,const QString &Text)
  if(mainWnd->MobileVersion)
  {
   QFont TempFont=qApp->font();
-  TempFont.setPixelSize(TempFont.pixelSize()/1.3);
+  mainWnd->scaleFont(TempFont,0.77);
   TextEdit->setFont(TempFont);
   QPalette pal = TextEdit->palette();
   pal.setBrush(QPalette::Base, mainWnd->palette().color(QPalette::Window));
@@ -998,7 +1073,7 @@ void MainWindow::nodeInformation()
   showPageLoading();
   qApp->processEvents();
   QFont TempFont=qApp->font();
-  TempFont.setPixelSize(TempFont.pixelSize()/1.2);
+  scaleFont(TempFont,0.8);
   DetailsWindow->ui->labelNodeName->setText(style.arg(map->nodeClick->Route->color.name()).arg(map->nodeClick->DisplayName));
   DetailsWindow->ui->labelNodeName->setFont(TempFont);
   DetailsWindow->ui->labelNodeName->setVisible(1);
@@ -1027,12 +1102,12 @@ void MainWindow::nodeInformation()
   TMapNode::InfoItem Info=map->nodeClick->Info.value(key);
   if(Info.Type==TMapNode::itImage)
   {
-   QStringList Value=Info.Value.split("\n");
+   QStringList Value=Info.Value.split("\\n");
    foreach(QString FileName,Value)
    {
     layout = new QVBoxLayout;
     layout->setMargin(2);
-    MapScheme = new TMapView(appPath,cachePath);
+    MapScheme = new TMapView(appPath,appCachePath);
 
     MapScheme->setParent(DetailsWindow);
     MapScheme->state.mapLoaded=0;
@@ -1040,7 +1115,7 @@ void MainWindow::nodeInformation()
     //MapScheme->setAlignment(Qt::AlignCenter);
     //MapScheme->setTransformationAnchor(AnchorUnderMouse);
     MapScheme->params.mapColorBack=Qt::white;
-    MapScheme->params.mapPath=map->params.mapPath;
+    MapScheme->params.mapCachePath=map->params.mapCachePath;
     MapScheme->config.enableDrawBackground=1;
     //working bad//
     MapScheme->config.enableKineticScroll=MapScheme->config.enableCaching;
@@ -1049,7 +1124,7 @@ void MainWindow::nodeInformation()
 
     //MapScheme->setStyleSheet(TOOLBAR_STYLE.arg(Config.appIconSize));
 
-    map->extractFiles(map->params.mapFile,FileName,map->params.mapPath);
+    map->extractFiles(map->params.mapFile,FileName,map->params.mapCachePath);
     MapScheme->loadMapImageToPaintCmd(FileName,MapScheme->paintBkg);
     MapScheme->horizontalScrollBar()->setValue(MapScheme->horizontalScrollBar()->maximum()/2);
     MapScheme->verticalScrollBar()->setValue(MapScheme->verticalScrollBar()->maximum()/2);
@@ -1125,13 +1200,15 @@ void MainWindow::closeEvent(QCloseEvent * e)
  if(!isVisible()) { e->accept(); return;} // FIX: double exec dont know why
  map->state.mapLoaded=0;
  if(ui->dock->isVisible()) Config.dockWidth=ui->dock->width();
+
+ lower();
  hide();
  qApp->processEvents();
  QSettings ini(appConfigFile,QSettings::IniFormat);
  ini.setIniCodec(codePage);
  QString key;
  ini.beginGroup("Main");
- ini.setValue("Version", VERSION);
+ ini.setValue("Version", _DEF(VERSION));
  if(!MobileVersion)
  {
   ini.setValue("WindowState", saveState().toHex());
@@ -1153,9 +1230,9 @@ void MainWindow::closeEvent(QCloseEvent * e)
       ini.setValue(key,QPoint(map->horizontalScrollBar()->value(),map->verticalScrollBar()->value()));
  else ini.remove(key);
  // -> create default skin? // if(MobileVersion) ini.setValue("Styles",MAP_STYLE);
- if(AppConfig.value(igOther).value(ikMCleanCache).toInt()) removeDir(cachePath);
+ if(AppConfig.value(igOther).value(ikMCleanCache).toInt()) removeDir(appCachePath);
  else
- if(map->config.enableCaching && !QFile::exists(map->params.mapPath+".cache"))
+ if(map->config.enableCaching && !QFile::exists(map->params.mapCachePath+".cache"))
  {
   QList<QByteArray> supportFormats;
   supportFormats << QImageWriter::supportedImageFormats();
@@ -1170,10 +1247,10 @@ void MainWindow::closeEvent(QCloseEvent * e)
     if(!supportFormats.contains(format)) format=supportFormats.at(0);
    }
    //QImage img = map->CachedMap->toImage();
-   QImageWriter imgWriter(map->params.mapPath+".cache",format.toUpper());
+   QImageWriter imgWriter(map->params.mapCachePath+".cache",format.toUpper());
    if(imgWriter.canWrite())
         imgWriter.write(map->CachedMap->toImage());
-   else map->CachedMap->save(map->params.mapPath+".cache",format);
+   else map->CachedMap->save(map->params.mapCachePath+".cache",format);
   }
  }
  map->clearMap();
@@ -1244,7 +1321,7 @@ void applySettings(const IniSettingMap &settings)
       map->params.nodeFont=nodeFont;
  else map->params.nodeFont=map->params.nodeFontDefault;
  map->params.nodeTimeFont=map->params.nodeFont;
- map->params.nodeTimeFont.setPixelSize(map->params.nodeWidth*1.15);
+ map->params.nodeTimeFont.setPixelSize(map->params.nodeWidth*1.25);
 
  if(mainWnd->Config.mapKineticScrollCheck && map->config.enableCaching)
  {
@@ -1326,22 +1403,14 @@ void loadSettings()
   cfg.endGroup();
  }
 
- /////////////
- if(AppConfig.value(igMapView).value(ikStationFont).isEmpty())
- {
-  IniKeyMap key=AppConfig.value(igMapView);
-  key.insert(ikStationFont,map->params.nodeFont.toString());
-  AppConfig.erase(AppConfig.find(igMapView));
-  AppConfig.insert(igMapView,key);
- }
-
- // if(AppConfig.value(igMain).value(ikSkin).isEmpty())
- // {
- //  IniKeyMap key=AppConfig.value(igMain);
- //  key.insert(ikSkin,mainWnd->Config.appSkinName);
- //  AppConfig.erase(AppConfig.find(igMain));
- //  AppConfig.insert(igMain,key);
- // }
+//////////
+// if(AppConfig.value(igMapView).value(ikStationFont).isEmpty())
+// {
+//  IniKeyMap key=AppConfig.value(igMapView);
+//  key.insert(ikStationFont,map->params.nodeFont.toString());
+//  AppConfig.erase(AppConfig.find(igMapView));
+//  AppConfig.insert(igMapView,key);
+// }
 
  applySettings(AppConfig);
 // map->applyConfig();
@@ -1465,9 +1534,7 @@ void MainWindow::setScaleForUi(qreal UiScale,qreal UiButtonScale)
  }
 
  QFont font=Config.appFont;
- if(font.pixelSize()>0)
-      font.setPixelSize(font.pixelSize()*UiScale);
- else font.setPointSizeF(font.pointSizeF()*UiScale);
+ scaleFont(font,UiScale);
 
  qApp->setFont(font);
  qApp->setStyleSheet(STYLE_MAIN.arg(Config.appIconSize)          // 1
@@ -1484,3 +1551,10 @@ void MainWindow::setScaleForUi(qreal UiScale,qreal UiButtonScale)
  Config.appUiScale=UiScale;
  Config.appUiButtonScale=UiButtonScale;
 }
+
+void MainWindow::scaleFont(QFont &Font, const qreal &Factor)
+{
+ if(Font.pointSizeF()==-1)
+      Font.setPixelSize(Font.pixelSize()*Factor);
+ else Font.setPointSizeF(Font.pointSizeF()*Factor);
+}
