@@ -3,6 +3,7 @@
 #endif
 
 #include <QDebug>
+#include <QApplication>
 #include <QSettings>
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
@@ -132,8 +133,7 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
  state.mapDragging=0;
  params.delayIndex=params.delayToMetro=0;
  params.appPath=AppPath;
- params.mapCachePath=CachePath;
- params.appName=qApp->applicationName();
+ params.appCachePath=CachePath;
  codePage = QTextCodec::codecForName("Windows-1251");
  
  TimerPopup.setInterval(1000);
@@ -201,6 +201,7 @@ void TMapView::keyPressEvent(QKeyEvent *event)
     case Qt::Key_ZoomIn:
     case Qt::Key_VolumeDown:
 //    case Qt::Key_F7: // maemo volUp 16777270 // dont work
+        if(!config.enableZoomKeys) break;
         if(mapTrack.count()>1)
              showNextTrack();
         else zoomIn();
@@ -210,6 +211,7 @@ void TMapView::keyPressEvent(QKeyEvent *event)
     case Qt::Key_ZoomOut:
     case Qt::Key_VolumeUp:
 //    case Qt::Key_F8: // maemo volDown 16777271 // dont work
+        if(!config.enableZoomKeys) break;
         if(mapTrack.count()>1)
              showPreviousTrack();
         else zoomOut();
@@ -335,13 +337,13 @@ void TMapView::drawBackground(QPainter *painter, const QRectF &rect)
      CachedMap = new QPixmap(mapWidth+200,mapHeight+200);
      //CachedMap = new QImage(mapWidth,mapHeight,QImage::Format_RGB555);
      //CachedMap->fill(params.mapColorBack);
-     QString cacheImgPath = params.mapPath+".cache";
+     QString cacheImgPath = params.mapCachePath+".cache";
      QFileInfo cacheInfo(cacheImgPath);
      if(QFile::exists(cacheImgPath) && nodeByID.count())
      {
       if(cacheInfo.size()>1024)
       {
-       QImage img(mapWidth,mapHeight,QImage::Format_RGB555);
+       QImage img(mapWidth,mapHeight,QImage::Format_Indexed8);
        QImageReader imgReader(cacheImgPath,"PNG");
 //       if(imgReader.canRead())
 //            QPixmap::fromImageReader(&imgReader);
@@ -472,11 +474,11 @@ void TMapView::loadMap(QString fileName)
 
  fname=fname.left(fname.indexOf("."));
  params.mapFile=fileName;
- params.mapPath=params.mapCachePath+fname+"/";
- if(!extractFiles(fileName,fname+".cty;Metro.map;*.txt",params.mapPath)) return;
+ params.mapCachePath=params.appCachePath+fname+"/";
+ if(!extractFiles(fileName,fname+".cty;Metro.map;*.txt",params.mapCachePath)) return;
 
 
- INISettings cty(params.mapPath+fname+".cty",codePage);
+ INISettings cty(params.mapCachePath+fname+".cty",codePage);
  //cty.setIniCodec(codePage);
  cty.beginGroup("Options");
  params.mapName=cty.value("Name");
@@ -534,7 +536,7 @@ void TMapView::loadMap(QString fileName)
  //qDebug() << delayList;
  emit delayNames(delayList);
 
- INISettings ini(params.mapPath+"Metro.map",codePage);
+ INISettings ini(params.mapCachePath+"Metro.map",codePage);
 
  ini.beginGroup("Options");
  imageFile=ini.value("ImageFileName");
@@ -548,7 +550,7 @@ void TMapView::loadMap(QString fileName)
  params.mapIsVector=ini.value("IsVector","1",vtBoolean).toInt();
  params.Transports=ini.value("Transports","Metro.trp").split(',').join(";");
  params.CheckedTransports=ini.value("CheckedTransports","Metro.trp");
- if(imageFile.isEmpty() || !extractFiles(fileName,imageFile,params.mapPath)) return;
+ if(imageFile.isEmpty() || !extractFiles(fileName,imageFile,params.mapCachePath)) return;
 
  if(!config.enableCustomFont)
    params.nodeFontStyle=(params.nodeWordWrap ? Qt::TextWordWrap:Qt::TextSingleLine)+Qt::TextDontClip;
@@ -564,7 +566,7 @@ void TMapView::loadMap(QString fileName)
  scene->setItemIndexMethod(QGraphicsScene::NoIndex);
  loadMapImageToPaintCmd(imageFile,paintBkg);
  //qDebug() << params.Transports << params.CheckedTransports;
- extractFiles(fileName,params.Transports,params.mapPath);
+ extractFiles(fileName,params.Transports,params.mapCachePath);
  loadMapLayers(params.CheckedTransports);
  //qDebug() << ((TMapLayer*)layer.at(0))->route.count();
  addLayerToPaintCmd(layer.at(0),paintMap);
@@ -600,11 +602,11 @@ void TMapView::exportMap(QString fileName,QString ext)
  painter.setRenderHints(Antialiasing);
  drawBackground(&painter,scene->sceneRect());
  scene->render(&painter,rect,rect);
- QImageWriter imageWriter(fileName,ext.toLatin1());
- imageWriter.write(image);
- //image.save(fileName,ext.toLatin1());
+
+ writeImage(fileName,ext,image);
 }
 
+
 bool TMapView::extractFiles(QString zipFile, QString extractFiles, QString extractDir)
 {
  UnZip::ErrorCode ec;
@@ -613,7 +615,7 @@ bool TMapView::extractFiles(QString zipFile, QString extractFiles, QString extra
  ec = uz.openArchive(zipFile);
  if (ec != UnZip::Ok)
  {
-  QMessageBox::warning(0,params.appName,tr("Cannot open file mapping:\n%1").arg(zipFile));
+  QMessageBox::warning(0,QString(APPNAME),tr("Cannot open file mapping:\n%1").arg(zipFile));
   return 0;
  }
  //extractDir=QDir::convertSeparators(extractDir);
@@ -654,7 +656,7 @@ void TMapView::loadMapImageToPaintCmd(QString imageFile, QList<TPaintCmd> &paint
  }
 
  addPaintCmd("-1",dtBrushColor,paintBkg);
- imageFile=params.mapPath+imageFile;
+ imageFile=params.mapCachePath+imageFile;
  QFile file(imageFile);
  if (!file.open(QFile::ReadOnly | QFile::Text))
  {
@@ -721,8 +723,8 @@ void TMapView::addPaintCmd(const QString &eParam,DrawType eType,QList<TPaintCmd>
    int x=0,y=0;
    QStringList param = eParam.split(",");
    QString imageFile,ext=param.at(0).right(4).toUpper();
-   imageFile=params.mapPath+param.at(0);
-   if(!QFile::exists(imageFile)) extractFiles(params.mapFile,param.at(0),params.mapPath);
+   imageFile=params.mapCachePath+param.at(0);
+   if(!QFile::exists(imageFile)) extractFiles(params.mapFile,param.at(0),params.mapCachePath);
    if(param.count()>1)
    {
     x=param.at(1).toInt();
@@ -1089,11 +1091,11 @@ void TMapView::loadMapLayers(QString LayerFilesTRP)
 {
  QStringList list,tprlist=LayerFilesTRP.split(",",QString::SkipEmptyParts);
  int ind,nodeID=0;
- INISettings map(params.mapPath+"Metro.map",codePage);
+ INISettings map(params.mapCachePath+"Metro.map",codePage);
  foreach(const QString &file, tprlist)
  {
   TMapLayer *mapLayer = new TMapLayer();
-  INISettings trp(params.mapPath+file,codePage);
+  INISettings trp(params.mapCachePath+file,codePage);
   mapLayer->typeName=trp.value("Options/Type");
   int line=0;
 
@@ -1559,7 +1561,7 @@ void TMapView::addLayerToPaintCmd(TMapLayer *mapLayer,QList<TPaintCmd> &paintCmd
 
   tCmd = TPaintCmd();
 
-  tCmd.pen=QPen(params.mapColorBack.lighter(150),tWidth*qreal(1.2),Qt::SolidLine,Qt::SquareCap,Qt::MiterJoin);
+  tCmd.pen=QPen(params.mapColorBack.lighter(150),tWidth*qreal(1.2),Qt::SolidLine,Qt::FlatCap,Qt::MiterJoin);
   tCmd.type=dtPenColor;
   paintCmd << tCmd;
 
@@ -1776,12 +1778,13 @@ QString TMapView::getMessageTrackDescription(int index)
  QString line=" "+tr("line")+")";
  QString font="<table width=\"100%\" style=\"COLOR:white;BACKGROUND-COLOR:%1\"><tr><td align=\"center\"><b>&nbsp;%2</b><td width=0 align=\"right\">%3</tr></table>";
  QString smallTag="<small>%1</small>";
+ QString centerTag="<center>%1</center>";
 
  QString text=smallTag.arg("%4")+
       font.arg("%5").arg("%6").arg(smallTag.arg("%8"))+
-      "<center>"+smallTag.arg("%7")+"</center><hr>";
+      centerTag.arg(smallTag.arg("%7"))+"<hr>";
 
- text=text.arg(tr("Begin station:")) // 4
+ text=text.arg(centerTag.arg(tr("Begin station:"))) // 4
           .arg(nodeByID[mapTrack.at(index).station.first().id]->Route->color.name()) //5
           .arg(nodeByID[mapTrack.at(index).station.first().id]->DisplayName) //6
           .arg("("+nodeByID[mapTrack.at(index).station.first().id]->Route->DisplayName+line) //7
@@ -1791,11 +1794,11 @@ QString TMapView::getMessageTrackDescription(int index)
  {
   if(mapTrack.at(index).station.at(i).isTransfer)
   {
-   text+=smallTag.arg(tr("Go to station:"))+
+   text+=centerTag.arg(smallTag.arg(tr("Go to station:")))+
          font.arg(nodeByID[mapTrack.at(index).station.at(i).id]->Route->color.name())
          .arg(nodeByID[mapTrack.at(index).station.at(i).id]->DisplayName)
          .arg("<b>"+smallTag.arg(mapTrack.at(index).station.at(i).time.toString(tf))+"</b>")+
-         smallTag.arg(tr("Transfer to station:"))+
+         centerTag.arg(smallTag.arg(tr("Transfer to station:")))+
          font.arg(nodeByID[mapTrack.at(index).station.at(i+1).id]->Route->color.name())
          .arg(nodeByID[mapTrack.at(index).station.at(i+1).id]->DisplayName)
          .arg(smallTag.arg(mapTrack.at(index).station.at(i+1).time.toString(tf)))+"<hr>";
@@ -1803,7 +1806,7 @@ QString TMapView::getMessageTrackDescription(int index)
 
  }
 
- text+=smallTag.arg(tr("Final station:"))+
+ text+=centerTag.arg(smallTag.arg(tr("Final station:")))+
        font.arg(nodeByID[mapTrack.at(index).station.last().id]->Route->color.name())
            .arg(nodeByID[mapTrack.at(index).station.last().id]->DisplayName)
            .arg("<b>"+smallTag.arg(mapTrack.at(index).station.last().time.toString(tf))+"</b>")+
@@ -1834,67 +1837,12 @@ void TMapView::initWorkGraph(QVector< QVector<qreal> > &workGraph)
  }
 }
 
-void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal> > workGraph)
+void TMapView::findTrackInGraph(TMapNode *begin,TMapNode *end, QVector< QVector<qreal> > workGraph)
 {
- emit nodeClicked(1);
- if(!begin && end)
- {
-  nodeEndID=end->ID;
-  if(nodeEnd) nodeEnd->update();
-  nodeEnd=end;
-  end->update();
-  return;
- }
- if(!begin || begin->TypeNode==TMapNode::ntConstruct ||
-    begin==end /*|| (!end && begin==nodeBegin)*/ || (end && end->TypeNode==TMapNode::ntConstruct)) return;
-
- if(end==NULL) // click node: begin or end
- {
-  if(nodeBegin==NULL) nodeBegin=begin;
-  else
-  if(begin!=nodeBegin)nodeEnd=begin;
-
-  emit nodeHasInfo(nodeBegin && nodeBegin->HasInfo && !nodeEnd);
- }else
- {
-  nodeBegin=begin;
-  nodeEnd=end;
- }
-
-
- nodeBeginID=nodeBegin->ID;
- if(nodeEnd) nodeEndID=nodeEnd->ID;
- else        mapDistance.clear();
- //viewport()->repaint();
-// qApp->processEvents();
-
  // calc distances
- if(begin!=nodeEnd || !workGraph.count())
- {
-//  qDebug() << "graph: " <<workGraph.count();
-  if(!workGraph.count()) // end node is changed
-  {
-   mapTrack.clear();
-   initWorkGraph(workGraph);
-  }
   dijkstra(nodeBeginID,workGraph);
-  mapDistance[nodeBeginID]=params.delayToMetro*60;
- }
 
- if(!nodeEnd) // just show time to all stations
- {
-  // caching calculations
-  foreach(TMapNode *node,nodeByID)
-   if(mapDistance[node->ID]<INFINIT)
-        node->Distance=QString::number(int(mapDistance[node->ID]/60));
-   else node->Distance="";
-
-  viewport()->update(); //foreach(TMapNode *node,nodeByID) node->update();
-  return;
- }
-
-
- // find track
+ // find tracks
  QList<int> id;
  int endID=nodeEndID;
  id << endID;
@@ -1949,12 +1897,10 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal>
 
 // QString testnames; foreach(TMapTrack::TStation s,track.station) testnames+=s.name+" ";
 // qDebug() << ">>> "+testnames+"\n"<< track.countStation << track.countTransfer << track.countSecond;
-
 // qDebug() << mapTrack.count() << countTransfer;
+
  if(mapTrack.count()<9 && countTransfer && track.countSecond<mapTrack.at(0).countSecond*qreal(1.8)) // count of tracks
  {
-
-
   for(int i=0;i<track.station.count()-1;i++)
   {
    if(!workGraph.count()) break;
@@ -1966,7 +1912,7 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal>
     b=workGraph[track.station.at(i+1).id][track.station.at(i).id];
     workGraph[track.station.at(i).id][track.station.at(i+1).id]=0;
     workGraph[track.station.at(i+1).id][track.station.at(i).id]=0;
-    findTrack(nodeBegin,nodeEnd,workGraph);
+    findTrackInGraph(nodeBegin,nodeEnd,workGraph);
     workGraph[track.station.at(i).id][track.station.at(i+1).id]=a;
     workGraph[track.station.at(i+1).id][track.station.at(i).id]=b;
    }
@@ -1976,7 +1922,76 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal>
  }
  else workGraph.clear();
 
+}
 
+void TMapView::findTrack(TMapNode *begin,TMapNode *end)
+{
+ emit nodeClicked(1);
+
+ if(!begin && end)
+ {
+  nodeEndID=end->ID;
+  if(nodeEnd) nodeEnd->update();
+  nodeEnd=end;
+  end->update();
+  return;
+ }
+ if(!begin || begin->TypeNode==TMapNode::ntConstruct ||
+    begin==end /*|| (!end && begin==nodeBegin)*/ || (end && end->TypeNode==TMapNode::ntConstruct)) return;
+
+ if(end==NULL) // click node: begin or end
+ {
+  if(nodeBegin==NULL) nodeBegin=begin;
+  else
+  if(begin!=nodeBegin)nodeEnd=begin;
+
+  emit nodeHasInfo(nodeBegin && nodeBegin->HasInfo && !nodeEnd);
+ }else
+ {
+  nodeBegin=begin;
+  nodeEnd=end;
+ }
+
+ selectedNodesToFront(0);
+
+ nodeBeginID=nodeBegin->ID;
+ if(nodeEnd) nodeEndID=nodeEnd->ID;
+ else        mapDistance.clear();
+ //viewport()->repaint();
+
+ QVector< QVector<qreal> > workGraph;
+
+ // calc distances
+ if(begin!=nodeEnd || !workGraph.count())
+ {
+//  qDebug() << "graph: " <<workGraph.count();
+  if(!workGraph.count()) // end node is changed
+  {
+   mapTrack.clear();
+   initWorkGraph(workGraph);
+  }
+  dijkstra(nodeBeginID,workGraph);
+  mapDistance[nodeBeginID]=params.delayToMetro*60;
+ }
+
+
+ if(!nodeEnd) // just show time to all stations
+ {
+  // caching calculations
+  foreach(TMapNode *node,nodeByID)
+   if(mapDistance[node->ID]<INFINIT)
+        node->Distance=QString::number(int(mapDistance[node->ID]/60));
+   else node->Distance="";
+
+  viewport()->update(); //foreach(TMapNode *node,nodeByID) node->update();
+  return;
+ }
+ nodeBegin->setZValue(2);
+ nodeEnd->setZValue(2);
+ nodeEnd->update();
+ QApplication::processEvents();
+
+ findTrackInGraph(nodeBegin,nodeEnd,workGraph);
 
  // sorting tracks
  TMapTrack tmp;
@@ -2001,9 +2016,10 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal>
    }
    else min=i;
   }
- if(mapTrack.count()>1 && mapTrack.at(0).countTransfer!=mapTrack.at(min).countTransfer) mapTrack.swap(1,min);
+ if(mapTrack.count()>1 && mapTrack.at(0).countTransfer!=mapTrack.at(min).countTransfer) mapTrack.move(min,1); //swap(1,min);
 
 // qDebug() << "tracks: " << mapTrack.count();
+// for(int i=0;i<mapTrack.count();i++) qDebug() << i+1 << mapTrack.at(i).countSecond;
 
  QStringList trackList;
  if(!config.MobileVersion)
@@ -2020,9 +2036,12 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end, QVector< QVector<qreal>
 
 void TMapView::showTrack(int i)
 {
+// testTimer.start();
  if(i<0 || !mapTrack.count()) return;
 
  state.mapLoaded=0;
+// QApplication::processEvents();
+ mapStartDragging();
  QString info,text;
  selectedNodesToFront(0); // previous trackIndex
  selectedNode.clear();
@@ -2052,16 +2071,17 @@ void TMapView::showTrack(int i)
  emit trackText(text);
 
  if(config.MobileVersion && mapTrack.count()>1)
-   info="<sup><font face=monospace>&nbsp;"+QString::number(i+1)+"&nbsp;</font></sup>"+info;
+   info="<small><font face=monospace>&nbsp;"+QString::number(i+1)+".</font></small>"+info;
  emit trackInfo(info);
  emit trackFinded(1);
 
- mapStartDragging();
  trackIndex=i;
  selectedNodesToFront(1);
  //qDebug() << id;
  state.mapLoaded=1;
- viewport()->update();
+// viewport()->update();
+// qDebug() << testTimer.elapsed();
+ QApplication::processEvents();
 }
 
 void TMapView::showNextTrack()
@@ -2104,7 +2124,7 @@ void TMapView::clearTrack()
  emit nodeClicked(0);
  emit nodeHasInfo(0);
 
- if(config.MobileVersion) emit trackFinded(0); // hide LabelInfo
+ if(config.MobileVersion) emit trackFinded(0); // hide LabelInfo & Search
  else                     emit trackNames(QStringList()); // clear list of routes
  // viewport()->repaint();
  viewport()->update();
@@ -2172,22 +2192,22 @@ QList< QPair<QString,QColor> > TMapView::getNamesAndColors()
 void TMapView::defaultConfig()
 {
  QLocale::Country country=QLocale::system().country();
- QString city,mapDir="map/";
+ QString city;
 
  city="Moscow";
  if(country==QLocale::Ukraine) city="Kiev"; else
  if(country==QLocale::Mexico) city="Mexico"; else
  if(country==QLocale::France) city="Paris"; else
  if(country==QLocale::Netherlands) city="Amsterdam"; else
- if(country==QLocale::Czech) city="Praha"; else
- if(country==QLocale::Spanish) city="Madrid"; else
+ if(country==QLocale::Country(QLocale::Czech)) city="Praha"; else
+ if(country==QLocale::Country(QLocale::Spanish)) city="Madrid"; else
  if(country==QLocale::Canada) city="Montreal"; else
  if(country==QLocale::UnitedStates) city="New-York"; else
  if(country==QLocale::Belgium) city="Brussels"; else
  if(country==QLocale::Germany) city="Berlin"; else
  if(country==QLocale::Austria) city="Wienn"; else
  if(country==QLocale::UnitedKingdom) city="London"; else
- if(country==QLocale::Italy) city="Milan"; else
+ if(country==QLocale::Italy) city="Milano"; else
  if(country==QLocale::Finland) city="Helsinki"; else
  if(country==QLocale::Brazil) city="San-Paulo"; else
  if(country==QLocale::Thailand) city="Bangkok"; else
@@ -2198,12 +2218,12 @@ void TMapView::defaultConfig()
  if(country==QLocale::RepublicOfKorea) city="Seoul"; else
  if(country==QLocale::Japan) city="Tokyo";
 
- config.mapLastFile=params.appPath+mapDir+city+".pmz";
+ config.mapLastFile=params.appMapPath+city+".pmz";
 
  if(!QFile::exists(config.mapLastFile))
  {
-  QDir Dir=QDir(params.appPath+mapDir,"*.pmz",QDir::Name,QDir::Files);
-  if(!Dir.entryList().empty()) config.mapLastFile=params.appPath+mapDir+Dir.entryList().first();
+  QDir Dir=QDir(params.appMapPath,"*.pmz",QDir::Name,QDir::Files);
+  if(!Dir.entryList().empty()) config.mapLastFile=params.appMapPath+Dir.entryList().first();
  }
  //qDebug() << config.mapLastFile;
  config.enableCustomFont=0;
@@ -2247,7 +2267,7 @@ void TMapView::applyConfig()
 
  if(config.enableCaching && state.mapCached)
  {
-  QFile::remove(params.mapPath+".cache");
+  QFile::remove(params.mapCachePath+".cache");
   state.mapCached=0;
  }
 
@@ -2333,8 +2353,8 @@ QString TMapView::convertToTextWithTags(QString text)
 void TMapView::initNodeInfo()
 {
  QString HasInfoFileName=".info";
- QSettings inf(params.mapPath+HasInfoFileName,QSettings::IniFormat);
- if(QFile::exists(params.mapPath+HasInfoFileName))
+ QSettings inf(params.mapCachePath+HasInfoFileName,QSettings::IniFormat);
+ if(QFile::exists(params.mapCachePath+HasInfoFileName))
  {
   foreach(TMapRoute *route,layer.first()->route)
   {
@@ -2346,7 +2366,7 @@ void TMapView::initNodeInfo()
   }
   return;
  }
- QDir Dir=QDir(params.mapPath,"*.txt",QDir::Name,QDir::Files);
+ QDir Dir=QDir(params.mapCachePath,"*.txt",QDir::Name,QDir::Files);
  QStringList infoList=Dir.entryList();
  foreach(TMapRoute *route,layer.first()->route)
  {
@@ -2354,7 +2374,7 @@ void TMapView::initNodeInfo()
   inf.beginGroup(QString::number(route->ID));
   foreach(const QString &infoFile,infoList)
   {
-   INISettings Info(params.mapPath+infoFile,codePage);
+   INISettings Info(params.mapCachePath+infoFile,codePage);
    if(!Info.value("Options/AddToInfo",0).toInt()) continue;
 
    QString StrInfo;
@@ -2377,11 +2397,11 @@ void TMapView::initNodeInfo()
 void TMapView::loadNodeInfo(TMapNode *node)
 {
  if(node->Info.count()) return;
- QDir Dir=QDir(params.mapPath,"*.txt",QDir::Name,QDir::Files);
+ QDir Dir=QDir(params.mapCachePath,"*.txt",QDir::Name,QDir::Files);
  QStringList infoList=Dir.entryList();
  foreach(const QString &infoFile,infoList)
  {
-  INISettings Info(params.mapPath+infoFile,codePage);
+  INISettings Info(params.mapCachePath+infoFile,codePage);
   if(!Info.value("Options/AddToInfo",0).toInt()) continue;
 
   QString Caption,Type=Info.value("Type").toUpper();
