@@ -7,6 +7,9 @@
 #include <QGestureEvent>
 #include <QPinchGesture>
 
+#include <QImageWriter>
+#include <QThread>
+
 #include "mapelement.h"
 
 class TMapLayer;
@@ -16,6 +19,45 @@ class TMapEdge;
 class FlickCharm;
 //class TMapElement;
 
+
+ class TImageThreadWriter : public QObject
+{Q_OBJECT
+public:
+  TImageThreadWriter(QString FileName, QString Format, QImage Image):
+  imageThread(new QThread), imageWriter(new QImageWriter(FileName,Format.toLatin1())), imageData(Image)
+  {
+   this->moveToThread(imageThread);
+   connect(imageThread,SIGNAL(started()),this,SLOT(writeImage()));
+   connect(this,SIGNAL(doneWrite()),imageThread,SLOT(quit()));
+   connect(this,SIGNAL(doneWrite()),this,SLOT(releaseTimerStart()));
+   imageThread->start();
+  }
+  ~TImageThreadWriter() { delete imageThread; delete imageWriter; }
+
+  QThread *imageThread;
+  QImageWriter *imageWriter;
+  QImage imageData;
+
+private slots:
+  void writeImage()
+  {
+   if(imageWriter->canWrite()) imageWriter->write(imageData);
+   emit doneWrite();
+  }
+  void releaseTimerStart() { QTimer::singleShot(1000,this,SLOT(releaseImage())); }
+  void releaseImage()
+  {
+   if(imageThread->isRunning()) { releaseTimerStart(); return; }
+   imageData = QImage();
+   imageThread->deleteLater();
+   this->deleteLater();
+  }
+
+signals:
+  void doneWrite();
+};
+
+
 class TMapTrack
 {
 //     QString info;
@@ -148,7 +190,8 @@ public:
     int  strTimeToSec(const QString &strTime);
 
     void initWorkGraph(QVector<QVector<qreal> > &workGraph);
-    void findTrack(TMapNode *begin,TMapNode *end=NULL, QVector< QVector<qreal> > workGraph=QVector< QVector<qreal> >());
+    void findTrackInGraph(TMapNode *begin,TMapNode *end=NULL, QVector< QVector<qreal> > workGraph=QVector< QVector<qreal> >());
+    void findTrack(TMapNode *begin,TMapNode *end=NULL);
     void clearTrack();
     void selectedNodesToFront(bool enable);
     QString getMessageTrackInfo(int trackIndex, bool inLine=0);
@@ -157,6 +200,9 @@ public:
     void initTranslit();
     void convertToTranslit(QString &text);
 
+    QThread* writeImage(QString FileName, QString Format, QImage Image)
+    { TImageThreadWriter *writer = new TImageThreadWriter(FileName,Format,Image); return writer->imageThread; }
+
     QTimer TimerPopup, TimerDragging, TimerAlarm;
 
     QList<TMapLayer*> layer;
@@ -182,7 +228,6 @@ public:
     struct TParams
     {
      QString mapFile;
-     QString mapPath;
      QString mapCachePath;
      QString mapName;
      QString mapCityName;
@@ -212,7 +257,8 @@ public:
      QString CheckedTransports;
 
      QString appPath;
-     QString appName;
+     QString appCachePath;
+     QString appMapPath;
 
      int delayToMetro;
      int delayIndex;
@@ -241,6 +287,7 @@ public:
      bool enableTranslit;
      bool enableCaching;
      bool enableSwipeRoutes;
+     bool enableZoomKeys;
 
      bool enableKineticScroll;
 
@@ -271,6 +318,8 @@ public:
     QMenu *nodePopup;
     FlickCharm *fcharm;
 
+    int mapWidth,mapHeight;
+
 public slots:
  void setDelayMetro(int delay);
  void setDelayIndex(int index);
@@ -312,7 +361,7 @@ protected:
     //void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
 
 
-    int mapWidth,mapHeight;
+
     QRect mapRect;
 };
 
