@@ -12,7 +12,7 @@ extern QString STYLE_MAP,SKIN_DEFAULT;
 TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map),TextDesc(NULL)
 {Q_UNUSED(parent);
  Ui::MainWindow *ui=mainWnd->ui;
- int Spacing=qRound(mainWnd->Config.appIconSize/10);
+ int Spacing=qRound(mainWnd->Config.appIconSize/10.0);
  DefaultIconSize=QSize(mainWnd->Config.appIconSize,mainWnd->Config.appIconSize);
 
  lTop =new QHBoxLayout;
@@ -76,12 +76,7 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map),Text
   bInfo=createButtonFromAction(new QAction(ui->mAbout->icon(),tr("Information"),this));
   bInfo->setVisible(0);
 
-
   textInfo = new QLabel("");
-//  QFont TempFont=qApp->font();
-//  TempFont.setPixelSize(TempFont.pixelSize()/1.25);
-//  textInfo->setFont(TempFont);
-
   textInfo->setMinimumWidth(0);
   textInfo->setMinimumHeight(0);
   //textDescription->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Fixed);
@@ -144,9 +139,6 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map),Text
   pal.setBrush(QPalette::Base, mainWnd->palette().color(QPalette::Window));
   pal.setColor(QPalette::Text,mainWnd->palette().color(QPalette::Text));
   TextDesc->setPalette(pal);
-//  TempFont=qApp->font();
-//  TempFont.setPixelSize(TempFont.pixelSize()/1.2);
-//  TextDesc->setFont(TempFont);
   TextDesc->setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::TextSelectableByMouse);
   TextDesc->setReadOnly(1);
   TextDesc->setFrameShape(QFrame::NoFrame);
@@ -266,7 +258,7 @@ void TMobileUi::setToolbarIconSize(int Size)
  }
 
  QFont TempFont=qApp->font();
- TempFont.setPixelSize(TempFont.pixelSize()/1.25);
+ mainWnd->scaleFont(TempFont,0.8);
 
  QList<QLabel *> labels =  MapView->findChildren<QLabel *>();
  foreach(QLabel *l,labels)
