@@ -1,7 +1,13 @@
 #ifndef MOBILEUI_H
 #define MOBILEUI_H
 
+#include <qglobal.h>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui>
+#endif
+
 #include "mainwindow.h"
 
 class TMapView;
