@@ -17,11 +17,11 @@
 
 extern MainWindow *mainWnd;
 extern IniSettingMap AppConfig;
-extern QString appPath,appConfigFile,cachePath,SKIN_DEFAULT;
+extern QString appPath,appConfigFile,appCachePath,SKIN_DEFAULT;
 
 Settings::Settings(QWidget *parent) :
     QDialog(parent),
-    ui(new Ui::Settings),SBackColor(Qt::white),SShadowColor(Qt::white),MBackColor(Qt::white)
+    ui(new Ui::Settings),SBackColor(Qt::white),SShadowColor(Qt::white),MBackColor(Qt::white),flagReloadMap(0)
 {
  bool MobileVersion=mainWnd->MobileVersion;
  setWindowFlags(windowFlags() & (~Qt::WindowContextHelpButtonHint));
@@ -33,7 +33,7 @@ Settings::Settings(QWidget *parent) :
   int WindowWidth=0;
   foreach(QCheckBox *chk,checks)
   {
-   int width=fmWidth.width(chk->text());
+   int width=fmWidth.width(chk->text())+ui->bMEmptyExit->height();
    if(width>WindowWidth) WindowWidth=width;
   }
   checks.clear();
@@ -41,7 +41,7 @@ Settings::Settings(QWidget *parent) :
   WindowWidth+=5;
   setMinimumWidth(WindowWidth+50);
   setMaximumWidth(WindowWidth+100);
-  resize(WindowWidth,WindowWidth*1.6);
+  resize(WindowWidth,WindowWidth*1.75);
 
 
   //  QList<QGroupBox *> groups =  findChildren<QGroupBox *>();
@@ -79,6 +79,51 @@ Settings::Settings(QWidget *parent) :
   VLayout->setContentsMargins(2,2,mainWnd->Config.appIconSize/2,2);  // scroll area
  }
 
+#ifdef QMETRO_HAVE_UPDATE
+ QGroupBox *gbUpdate = new QGroupBox(this);
+ QVBoxLayout *VLayout = new QVBoxLayout;
+ QHBoxLayout *HLayout1 = new QHBoxLayout;
+ QHBoxLayout *HLayout2 = new QHBoxLayout;
+ checkUpdate = new QCheckBox(gbUpdate);
+ spinDays = new QSpinBox(gbUpdate);
+ QPushButton *bCheckNow = new QPushButton(gbUpdate);
+ QLabel *labelLastCheckStr = new QLabel(gbUpdate);
+ labelLastCheckDate = new QLabel(gbUpdate);
+ ui->lgbOther->addWidget(gbUpdate);
+ gbUpdate->setTitle(tr("Update when starts"));
+ checkUpdate->setText(tr("Interval for check:"));
+ spinDays->setSuffix(QString(" %1").arg(tr("Days")));
+ spinDays->setEnabled(0);
+ spinDays->setMaximum(365);
+ spinDays->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
+ bCheckNow->setText(tr("Check Now"));
+ bCheckNow->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
+ labelLastCheckStr->setText(tr("Last check:"));
+ labelLastCheckStr->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
+ labelLastCheckDate->setAlignment(Qt::AlignCenter);
+ labelLastCheckDate->setWordWrap(1);
+
+ QFont font = checkUpdate->font();
+ mainWnd->scaleFont(font,0.85);
+ labelLastCheckStr->setFont(font);
+ labelLastCheckDate->setFont(font);
+ spinDays->setFont(font);
+
+ VLayout->setContentsMargins(5,2,6,2);
+ gbUpdate->setLayout(VLayout);
+ VLayout->addItem(HLayout1);
+ VLayout->addItem(HLayout2);
+ HLayout1->addWidget(checkUpdate);
+ HLayout1->addWidget(spinDays);
+ HLayout2->addWidget(labelLastCheckStr);
+ HLayout2->addWidget(labelLastCheckDate);
+ HLayout2->addWidget(bCheckNow);
+
+ connect(checkUpdate,SIGNAL(toggled(bool)),spinDays,SLOT(setEnabled(bool)));
+ connect(bCheckNow,SIGNAL(clicked()),mainWnd->Updater,SLOT(checkNow()));
+ connect(mainWnd->Updater,SIGNAL(onCheckNow(QString)),labelLastCheckDate,SLOT(setText(QString)));
+#endif
+
 #ifdef Q_OS_SYMBIAN // QDialogButtonBox not supported - replaced QPushButton
  ui->buttonBox->hide();
  QHBoxLayout *HLayout = new QHBoxLayout;
@@ -125,9 +170,12 @@ Settings::Settings(QWidget *parent) :
 
  //if(!QFile::exists(appConfigFile)) saveSettings(changeSettings());
 
- QDir skinDir=QDir(appPath+"skin/","*",QDir::Name,QDir::Dirs|QDir::NoDotAndDotDot);
+ QDir skinDir=QDir(appPath+"skin/","*",QDir::Name,QDir::Dirs|QDir::NoDotAndDotDot|QDir::Hidden);
  foreach(QString skinName,skinDir.entryList())
-   ui->cbSkin->addItem(QIcon(":/img/bullet.png"),skinName);
+ {
+  if(skinName.at(0)=='.') skinName.remove(0,1);
+  ui->cbSkin->addItem(QIcon(":/img/bullet.png"),skinName);
+ }
 
  //foreach(QString style,QStyleFactory::keys())  ui->cbSkin->addItem(QIcon(""),style);
  ui->cbSkin->addItems(QStyleFactory::keys());
@@ -176,6 +224,10 @@ Settings::Settings(QWidget *parent) :
   setAttribute(Qt::WA_DeleteOnClose);
  }
 
+// connect(ui->checkSCustomFont,SIGNAL(clicked()),this,SLOT(setFlagReloadMap()));
+// connect(ui->checkSWordWrap,SIGNAL(clicked()),this,SLOT(setFlagReloadMap()));
+ connect(ui->checkMSimpleTransfers,SIGNAL(clicked()),this,SLOT(setFlagReloadMap()));
+ connect(ui->bMBackColor,SIGNAL(clicked()),this,SLOT(setFlagReloadMap()));
 }
 
 void Settings::showEvent(QShowEvent *e)
@@ -222,18 +274,29 @@ void Settings::on_bSShadowColor_clicked()
 void Settings::on_bMBackColor_clicked()
 { getColorFromDialog(ui->bMBackColor,MBackColor); }
 
-QFont getFontFromLabel(QLabel *Label)
+QFont Settings::getFontFromLabel(QLabel *Label)
 {
  QFont Font;
- Font=Label->font();
+ if(Label->text().isEmpty())
+ {
+  setFontToLabel(Label,mainWnd->map->params.nodeFontDefault);
+  ui->checkSUpperCase->setChecked(mainWnd->map->params.nodeUpperCase);
+  ui->checkSWordWrap->setChecked(mainWnd->map->params.nodeWordWrap);
+//  ui->checkSBackColor->setChecked(mainWnd->map->config.enableStationBackColor);
+//  ui->checkSShadow->setChecked(mainWnd->map->config.enableStationShadowColor);
+  return mainWnd->map->params.nodeFontDefault;
+ }
+ else Font=Label->font();
+
+ qreal Size=Label->text().section(",",-1).trimmed().toFloat();
  if(Font.pointSizeF()==-1)
-      Font.setPixelSize(Font.pixelSize());
- else Font.setPointSizeF(Font.pointSizeF());
- //Font.setPointSizeF(s->text().section(",",-1).toFloat());
+      Font.setPixelSize(Size);
+ else Font.setPointSizeF(Size);
+
  return Font;
 }
 
-void setFontToLabel(QLabel *Label,QFont &Font)
+void Settings::setFontToLabel(QLabel *Label,QFont Font)
 {
  qreal Size=(Font.pointSizeF()==-1 ? Font.pixelSize():Font.pointSizeF());
  if(Label->font().pointSizeF()==-1)
@@ -255,7 +318,16 @@ void Settings::on_bSFont_clicked()
 void Settings::on_buttonBox_accepted()
 {
   saveSettings(changeSettings());
-  emit closed();
+#ifdef QMETRO_HAVE_UPDATE
+ QSettings ini(appConfigFile,QSettings::IniFormat);
+ ini.beginGroup("Update");
+ ini.setValue("Enable",int(checkUpdate->isChecked()));
+ ini.setValue("RefreshDay",spinDays->value());
+#endif
+
+ if(flagReloadMap) mainWnd->reloadMap();
+
+ emit closed();
 }
 
 void Settings::on_buttonBox_rejected()
@@ -274,6 +346,11 @@ void Settings::on_bDefaultConfig_clicked()
  ui->checkMSwipeRoutes->setChecked(mainWnd->MobileVersion);
  ui->cbSkin->setCurrentIndex(ui->cbSkin->findText(SKIN_DEFAULT,Qt::MatchFixedString));
 
+#ifdef QMETRO_HAVE_UPDATE
+ checkUpdate->setChecked(1);
+ spinDays->setValue(28);
+#endif
+
  // apply
  if(!mainWnd->MobileVersion) changeSettings();
 }
@@ -330,10 +407,14 @@ void Settings::loadSettingsToUi(const IniSettingMap &set)
  IniKeyMap key;
  QString value;
 
+ setUpdatesEnabled(0);
+ blockSignals(1);
+
  QFont font;
  value=set.value(igMapView).value(ikStationFont);
- if(!value.isEmpty()) font.fromString(value);
- else                 font=mainWnd->map->params.nodeFontDefault; //map->font(); //mainWnd->Config.appFont;
+ if(!value.isEmpty())
+      font.fromString(value);
+ else font=mainWnd->map->params.nodeFontDefault; //map->font(); //mainWnd->Config.appFont;
 // qDebug() << font;
  setFontToLabel(ui->labelSFont,font);
 
@@ -405,17 +486,30 @@ void Settings::loadSettingsToUi(const IniSettingMap &set)
  else ui->checkMSwipeRoutes->setChecked(mainWnd->map->config.enableSwipeRoutes);
  //set.value(igMapView).value().toInt()
 
+#ifdef QMETRO_HAVE_UPDATE
+ QSettings ini(appConfigFile,QSettings::IniFormat);
+ ini.beginGroup("Update");
+ checkUpdate->setChecked(ini.value("Enable",1).toBool());
+ spinDays->setValue(ini.value("RefreshDay",28).toInt());
+ labelLastCheckDate->setText(ini.value("Date").toDateTime().toString(Qt::SystemLocaleShortDate).remove(QRegExp(":\\d\\d($|\\s)")));
+ if(labelLastCheckDate->text().isEmpty()) labelLastCheckDate->setText(tr("never"));
+#endif
+
+ flagReloadMap=0;
+
+ setUpdatesEnabled(1);
+ blockSignals(0);
 }
 
 void Settings::on_bMEmptyExit_clicked()
 {
- removeDir(cachePath);
+ removeDir(appCachePath);
  updateLabelCacheSize();
 }
 
 void Settings::updateLabelCacheSize()
 {
- qreal Size=sizeOfDir(cachePath)/1024;
+ qreal Size=sizeOfDir(appCachePath)/1024;
 
  QString Ext="Kb";
 
@@ -423,7 +517,7 @@ void Settings::updateLabelCacheSize()
  if(Size>1024) {Size=Size/1024; Ext="Gb";}
  if(Size>1024) {Size=Size/1024; Ext="Tb";}
 
- ui->labelCacheSize->setText(QString("%1 %2").arg((Size-int(Size)>0 ? QString::number(Size,'f',2):QString::number(Size))).arg(Ext));
+ ui->labelCacheSize->setText(QString("%1 %2 ").arg((Size-int(Size)>0 ? QString::number(Size,'f',2):QString::number(Size))).arg(Ext));
 }
 
 
