@@ -8,6 +8,10 @@ namespace Ui {
     class Settings;
 }
 
+class QCheckBox;
+class QSpinBox;
+class QLabel;
+
 class Settings : public QDialog
 {
     Q_OBJECT
@@ -25,6 +29,13 @@ private:
     void updateLabelCacheSize();
 
     QColor SBackColor,SShadowColor,MBackColor;
+    bool flagReloadMap;
+
+#ifdef QMETRO_HAVE_UPDATE
+    QCheckBox *checkUpdate;
+    QSpinBox *spinDays;
+    QLabel *labelLastCheckDate;
+#endif
 
 protected:
     void keyPressEvent(QKeyEvent *e);
@@ -46,8 +57,11 @@ private slots:
 
     IniSettingMap changeSettings();
 
-
+    QFont getFontFromLabel(QLabel *Label);
+    void setFontToLabel(QLabel *Label,QFont Font);
     void on_bDefaultConfig_clicked();
+    void setFlagReloadMap(){ flagReloadMap=1; }
+
 };
 
 #endif // SETTINGS_H
